==> batch-sdk-3.1.0-sources.jar: com/batch/android/core/ParameterKeys.java <==
package com.batch.android.core;

//@formatter:off

/**
 * Contains all parameters keys
 *
 */
public final class ParameterKeys
{
    public final static String START_WS_PROPERTY_KEY					= "ws.start.property";
    public final static String START_WS_URLSORTER_PATTERN_KEY			= "ws.start.pattern";
    public final static String START_WS_CRYPTORTYPE_KEY					= "ws.start.getcryptor.type";
    public final static String START_WS_CRYPTORMODE_KEY					= "ws.start.getcryptor.mode";
    public final static String START_WS_POST_CRYPTORTYPE_KEY			= "ws.start.postcryptor.type";
    public final static String START_WS_READ_CRYPTORTYPE_KEY			= "ws.start.readcryptor.type";
    public final static String START_WS_RETRYCOUNT_KEY					= "ws.start.retry";
    public final static String START_WS_CONNECT_TIMEOUT_KEY				= "ws.start.connect.timeout";
    public final static String START_WS_READ_TIMEOUT_KEY				= "ws.start.read.timeout";

    public final static String TRACKER_WS_PROPERTY_KEY					= "ws.tracker.property";
    public final static String TRACKER_WS_URLSORTER_PATTERN_KEY			= "ws.tracker.pattern";
    public final static String TRACKER_WS_CRYPTORTYPE_KEY				= "ws.tracker.getcryptor.type";
    public final static String TRACKER_WS_CRYPTORMODE_KEY				= "ws.tracker.getcryptor.mode";
    public final static String TRACKER_WS_POST_CRYPTORTYPE_KEY			= "ws.tracker.postcryptor.type";
    public final static String TRACKER_WS_READ_CRYPTORTYPE_KEY			= "ws.tracker.readcryptor.type";
    public final static String TRACKER_WS_RETRYCOUNT_KEY				= "ws.tracker.retry";
    public final static String TRACKER_WS_CONNECT_TIMEOUT_KEY			= "ws.tracker.connect.timeout";
    public final static String TRACKER_WS_READ_TIMEOUT_KEY				= "ws.tracker.read.timeout";

    public final static String PUSH_WS_PROPERTY_KEY						= "ws.push.property";
    public final static String PUSH_WS_URLSORTER_PATTERN_KEY			= "ws.push.pattern";
    public final static String PUSH_WS_CRYPTORTYPE_KEY					= "ws.push.getcryptor.type";
    public final static String PUSH_WS_CRYPTORMODE_KEY					= "ws.push.getcryptor.mode";
    public final static String PUSH_WS_POST_CRYPTORTYPE_KEY				= "ws.push.postcryptor.type";
    public final static String PUSH_WS_READ_CRYPTORTYPE_KEY				= "ws.push.readcryptor.type";
    public final static String PUSH_WS_RETRYCOUNT_KEY					= "ws.push.retry";
    public final static String PUSH_WS_CONNECT_TIMEOUT_KEY				= "ws.push.connect.timeout";
    public final static String PUSH_WS_READ_TIMEOUT_KEY					= "ws.push.read.timeout";

    public final static String IMAGE_WS_URLSORTER_PATTERN_KEY			= "ws.image.pattern";
    public final static String IMAGE_WS_CRYPTORTYPE_KEY					= "ws.image.getcryptor.type";
    public final static String IMAGE_WS_CRYPTORMODE_KEY					= "ws.image.getcryptor.mode";
    public final static String IMAGE_WS_POST_CRYPTORTYPE_KEY			= "ws.image.postcryptor.type";
    public final static String IMAGE_WS_READ_CRYPTORTYPE_KEY			= "ws.image.readcryptor.type";
    public final static String IMAGE_WS_RETRYCOUNT_KEY					= "ws.image.retry";
    public final static String IMAGE_WS_CONNECT_TIMEOUT_KEY				= "ws.image.connect.timeout";
    public final static String IMAGE_WS_READ_TIMEOUT_KEY				= "ws.image.read.timeout";

    public final static String ATTR_SEND_WS_PROPERTY_KEY				= "ws.attrsend.property";
    public final static String ATTR_SEND_WS_URLSORTER_PATTERN_KEY		= "ws.attrsend.pattern";
    public final static String ATTR_SEND_WS_CRYPTORTYPE_KEY				= "ws.attrsend.getcryptor.type";
    public final static String ATTR_SEND_WS_CRYPTORMODE_KEY				= "ws.attrsend.getcryptor.mode";
    public final static String ATTR_SEND_WS_POST_CRYPTORTYPE_KEY		= "ws.attrsend.postcryptor.type";
    public final static String ATTR_SEND_WS_READ_CRYPTORTYPE_KEY		= "ws.attrsend.readcryptor.type";
    public final static String ATTR_SEND_WS_RETRYCOUNT_KEY				= "ws.attrsend.retry";
    public final static String ATTR_SEND_WS_CONNECT_TIMEOUT_KEY			= "ws.attrsend.connect.timeout";
    public final static String ATTR_SEND_WS_READ_TIMEOUT_KEY			= "ws.attrsend.read.timeout";

    public final static String ATTR_CHECK_WS_PROPERTY_KEY				= "ws.attrcheck.property";
    public final static String ATTR_CHECK_WS_URLSORTER_PATTERN_KEY		= "ws.attrcheck.pattern";
    public final static String ATTR_CHECK_WS_CRYPTORTYPE_KEY			= "ws.attrcheck.getcryptor.type";
    public final static String ATTR_CHECK_WS_CRYPTORMODE_KEY			= "ws.attrcheck.getcryptor.mode";
    public final static String ATTR_CHECK_WS_POST_CRYPTORTYPE_KEY		= "ws.attrcheck.postcryptor.type";
    public final static String ATTR_CHECK_WS_READ_CRYPTORTYPE_KEY		= "ws.attrcheck.readcryptor.type";
    public final static String ATTR_CHECK_WS_RETRYCOUNT_KEY				= "ws.attrcheck.retry";
    public final static String ATTR_CHECK_WS_CONNECT_TIMEOUT_KEY		= "ws.attrcheck.connect.timeout";
    public final static String ATTR_CHECK_WS_READ_TIMEOUT_KEY			= "ws.attrcheck.read.timeout";


    public final static String ATTR_LOCAL_CAMPAIGNS_WS_PROPERTY_KEY					= "ws.localcampaigns.property";
    public final static String ATTR_LOCAL_CAMPAIGNS_WS_URLSORTER_PATTERN_KEY		= "ws.localcampaigns.pattern";
    public final static String ATTR_LOCAL_CAMPAIGNS_WS_CRYPTORTYPE_KEY				= "ws.localcampaigns.getcryptor.type";
    public final static String ATTR_LOCAL_CAMPAIGNS_WS_CRYPTORMODE_KEY				= "ws.localcampaigns.getcryptor.mode";
    public final static String ATTR_LOCAL_CAMPAIGNS_WS_POST_CRYPTORTYPE_KEY			= "ws.localcampaigns.postcryptor.type";
    public final static String ATTR_LOCAL_CAMPAIGNS_WS_READ_CRYPTORTYPE_KEY			= "ws.localcampaigns.readcryptor.type";
    public final static String ATTR_LOCAL_CAMPAIGNS_WS_RETRYCOUNT_KEY				= "ws.localcampaigns.retry";
    public final static String ATTR_LOCAL_CAMPAIGNS_WS_CONNECT_TIMEOUT_KEY			= "ws.localcampaigns.connect.timeout";
    public final static String ATTR_LOCAL_CAMPAIGNS_WS_READ_TIMEOUT_KEY				= "ws.localcampaigns.read.timeout";

    public final static String LOCAL_CAMPAIGNS_JIT_WS_PROPERTY_KEY					= "ws.localcampaignsjit.property";
    public final static String LOCAL_CAMPAIGNS_JIT_WS_URLSORTER_PATTERN_KEY		    = "ws.localcampaignsjit.pattern";
    public final static String LOCAL_CAMPAIGNS_JIT_WS_CRYPTORTYPE_KEY				= "ws.localcampaignsjit.getcryptor.type";
    public final static String LOCAL_CAMPAIGNS_JIT_WS_CRYPTORMODE_KEY				= "ws.localcampaignsjit.getcryptor.mode";
    public final static String LOCAL_CAMPAIGNS_JIT_WS_POST_CRYPTORTYPE_KEY			= "ws.localcampaignsjit.postcryptor.type";
    public final static String LOCAL_CAMPAIGNS_JIT_WS_READ_CRYPTORTYPE_KEY			= "ws.localcampaignsjit.readcryptor.type";
    public final static String LOCAL_CAMPAIGNS_JIT_WS_RETRYCOUNT_KEY	            = "ws.localcampaignsjit.retry";
    public final static String LOCAL_CAMPAIGNS_JIT_WS_READ_TIMEOUT_KEY              = "ws.localcampaignsjit.read.timeout";
    public final static String LOCAL_CAMPAIGNS_JIT_WS_CONNECT_TIMEOUT_KEY           = "ws.localcampaignsjit.connect.timeout";

    public final static String INBOX_WS_URLSORTER_PATTERN_KEY			= "ws.inbox.pattern";
    public final static String INBOX_WS_READ_CRYPTORTYPE_KEY			= "ws.inbox.readcryptor.type";
    public final static String INBOX_WS_POST_CRYPTORTYPE_KEY			= "ws.inbox.postcryptor.type";
    public final static String INBOX_WS_RETRYCOUNT_KEY					= "ws.inbox.retry";
    public final static String INBOX_WS_CONNECT_TIMEOUT_KEY				= "ws.inbox.connect.timeout";
    public final static String INBOX_WS_READ_TIMEOUT_KEY				= "ws.inbox.read.timeout";

    // Default MsgPack webservice parameters
    public final static String MESSAGE_PACK_WS_POST_CRYPTORTYPE_KEY	    = "ws.msgpack.postcryptor.type";
    public final static String MESSAGE_PACK_WS_READ_CRYPTORTYPE_KEY		= "ws.msgpack.readcryptor.type";
    public final static String MESSAGE_PACK_WS_URLSORTER_PATTERN_KEY	= "ws.msgpack.pattern";
    public final static String MESSAGE_PACK_WS_CRYPTORTYPE_KEY	        = "ws.msgpack.getcryptor.type";
    public final static String MESSAGE_PACK_WS_CRYPTORMODE_KEY          = "ws.msgpack.getcryptor.mode";
    public final static String MESSAGE_PACK_WS_RETRYCOUNT_KEY			= "ws.msgpack.retry";
    public final static String MESSAGE_PACK_WS_CONNECT_TIMEOUT_KEY		= "ws.msgpack.connect.timeout";
    public final static String MESSAGE_PACK_WS_READ_TIMEOUT_KEY			= "ws.msgpack.read.timeout";

    public final static String DISPLAY_RECEIPT_WS_CRYPTORTYPE_KEY	    =   "ws.displayreceipt.getcryptor.type";
    public final static String DISPLAY_RECEIPT_WS_RETRYCOUNT_KEY	    =   "ws.displayreceipt.retry";
    public final static String METRIC_WS_RETRYCOUNT_KEY	                =   "ws.metrics.retry";

    public final static String LOCAL_CAMPAIGNS_WS_INITIAL_DELAY         = "lc.wsdelay.initial";
    public final static String WS_CIPHERV2_LAST_FAILURE_KEY             = "ws.cipherv2.lastfailure";
    public final static String DEFAULT_RETRY_NUMBER_KEY					= "ws.defaultRetry";
    public final static String DEFAULT_CONNECT_TIMEOUT_KEY				= "ws.defaultconnectTimeout";
    public final static String DEFAULT_READ_TIMEOUT_KEY					= "ws.defaultreadTimeout";
    public final static String INSTALL_ID_KEY 							= "app.install.id";
    public final static String INSTALL_TIMESTAMP_KEY 					= "app.install.timestamp";
    public final static String TASK_EXECUTOR_MIN_POOL					= "app.executor.minpool";
    public final static String TASK_EXECUTOR_MAX_POOL					= "app.executor.maxpool";
    public final static String TASK_EXECUTOR_THREADTTL					= "app.executor.threadttl";
    public final static String SCHEME_CODE_PATTERN						= "app.scheme.codepattern";
    public final static String CUSTOM_ID								= "app.id.custom";
    public final static String USER_DATA_VERSION						= "app.profile.version";
    public final static String PROJECT_KEY						        = "app.project.key";
    public final static String SERVER_TIMESTAMP							= "ws.server.timestamp";
    public final static String EVENT_TRACKER_INITIAL_DELAY				= "tracker.delay.initial";
    public final static String EVENT_TRACKER_MAX_DELAY					= "tracker.delay.max";
    public final static String EVENT_TRACKER_BATCH_QUANTITY				= "tracker.batch.quantity";
    public final static String EVENT_TRACKER_EVENTS_LIMIT				= "tracker.db.limit";
    public final static String PUSH_REGISTRATION_ID_KEY					= "push.registration.id";
    public final static String PUSH_REGISTRATION_PROVIDER_KEY			= "push.registration.provider";
    public final static String PUSH_REGISTRATION_SENDERID_KEY			= "push.registration.sender_id";

    public final static String PUSH_REGISTRATION_GCPPROJECTID_KEY		= "push.registration.gcp_project_id";
    public final static String PUSH_APP_VERSION_KEY						= "push.appversion";
    public final static String PUSH_NOTIF_TYPE							= "push.notiftype";
    public final static String PUSH_NOTIF_LAST_AUTH_STATUS_SENT		    = "push.notif.last_auth_status_sent";

    public final static String USER_DATA_CHANGESET						= "user_profile.data.version";
    public final static String USER_DATA_TRANSACTION_ID					= "user_profile.data.transactionID";
    public final static String USER_PROFILE_LANGUAGE_KEY                = "u_c_l";
    public final static String USER_PROFILE_REGION_KEY                  = "u_c_r";

    public final static String LIB_CURRENTVERSION_KEY					= "app.version.current";
    public final static String LIB_PREVIOUSVERSION_KEY					= "app.version.previous";

    public final static String DISPLAY_RECEIPTS_JOB_CANCELLED_KEY	    = "displayreceipts.jobs.already_cancelled";

    public final static String SHARED_PREFS_STORAGE_VERSION				= "app.shared_prefs.version";

    public final static String DATA_COLLECTION_CONFIG_KEY			    = "data.privacy.config";

    // DNS Fallback
    public final static String DNS_DOMAIN_KEY                           = "dns.domain.current";
    public static final String DNS_DOMAIN_ERROR_COUNT_KEY               = "dns.domain.current.error.count";
    public static final String DNS_DOMAIN_ERROR_UPDATE_DATE             = "dns.domain.current.error.last_update.date";
    public static final String DNS_DOMAIN_LAST_UPDATE_DATE              = "dns.domain.current.last_update.date";
    public static final String DNS_DOMAIN_LAST_CHECK_DATE               = "dns.domain.original.last_check.date";
}
//@formatter:on

==> batch-sdk-3.2.0-sources.jar: com/batch/android/core/ParameterKeys.java <==
package com.batch.android.core;

//@formatter:off

/**
 * Contains all parameters keys
 *
 */
public final class ParameterKeys
{
    public final static String START_WS_PROPERTY_KEY					= "ws.start.property";
    public final static String START_WS_URLSORTER_PATTERN_KEY			= "ws.start.pattern";
    public final static String START_WS_CRYPTORTYPE_KEY					= "ws.start.getcryptor.type";
    public final static String START_WS_CRYPTORMODE_KEY					= "ws.start.getcryptor.mode";
    public final static String START_WS_POST_CRYPTORTYPE_KEY			= "ws.start.postcryptor.type";
    public final static String START_WS_READ_CRYPTORTYPE_KEY			= "ws.start.readcryptor.type";
    public final static String START_WS_RETRYCOUNT_KEY					= "ws.start.retry";
    public final static String START_WS_CONNECT_TIMEOUT_KEY				= "ws.start.connect.timeout";
    public final static String START_WS_READ_TIMEOUT_KEY				= "ws.start.read.timeout";

    public final static String TRACKER_WS_PROPERTY_KEY					= "ws.tracker.property";
    public final static String TRACKER_WS_URLSORTER_PATTERN_KEY			= "ws.tracker.pattern";
    public final static String TRACKER_WS_CRYPTORTYPE_KEY				= "ws.tracker.getcryptor.type";
    public final static String TRACKER_WS_CRYPTORMODE_KEY				= "ws.tracker.getcryptor.mode";
    public final static String TRACKER_WS_POST_CRYPTORTYPE_KEY			= "ws.tracker.postcryptor.type";
    public final static String TRACKER_WS_READ_CRYPTORTYPE_KEY			= "ws.tracker.readcryptor.type";
    public final static String TRACKER_WS_RETRYCOUNT_KEY				= "ws.tracker.retry";
    public final static String TRACKER_WS_CONNECT_TIMEOUT_KEY			= "ws.tracker.connect.timeout";
    public final static String TRACKER_WS_READ_TIMEOUT_KEY				= "ws.tracker.read.timeout";

    public final static String PUSH_WS_PROPERTY_KEY						= "ws.push.property";
    public final static String PUSH_WS_URLSORTER_PATTERN_KEY			= "ws.push.pattern";
    public final static String PUSH_WS_CRYPTORTYPE_KEY					= "ws.push.getcryptor.type";
    public final static String PUSH_WS_CRYPTORMODE_KEY					= "ws.push.getcryptor.mode";
    public final static String PUSH_WS_POST_CRYPTORTYPE_KEY				= "ws.push.postcryptor.type";
    public final static String PUSH_WS_READ_CRYPTORTYPE_KEY				= "ws.push.readcryptor.type";
    public final static String PUSH_WS_RETRYCOUNT_KEY					= "ws.push.retry";
    public final static String PUSH_WS_CONNECT_TIMEOUT_KEY				= "ws.push.connect.timeout";
    public final static String PUSH_WS_READ_TIMEOUT_KEY					= "ws.push.read.timeout";

    public final static String IMAGE_WS_URLSORTER_PATTERN_KEY			= "ws.image.pattern";
    public final static String IMAGE_WS_CRYPTORTYPE_KEY					= "ws.image.getcryptor.type";
    public final static String IMAGE_WS_CRYPTORMODE_KEY					= "ws.image.getcryptor.mode";
    public final static String IMAGE_WS_POST_CRYPTORTYPE_KEY			= "ws.image.postcryptor.type";
    public final static String IMAGE_WS_READ_CRYPTORTYPE_KEY			= "ws.image.readcryptor.type";
    public final static String IMAGE_WS_RETRYCOUNT_KEY					= "ws.image.retry";
    public final static String IMAGE_WS_CONNECT_TIMEOUT_KEY				= "ws.image.connect.timeout";
    public final static String IMAGE_WS_READ_TIMEOUT_KEY				= "ws.image.read.timeout";

    public final static String ATTR_SEND_WS_PROPERTY_KEY				= "ws.attrsend.property";
    public final static String ATTR_SEND_WS_URLSORTER_PATTERN_KEY		= "ws.attrsend.pattern";
    public final static String ATTR_SEND_WS_CRYPTORTYPE_KEY				= "ws.attrsend.getcryptor.type";
    public final static String ATTR_SEND_WS_CRYPTORMODE_KEY				= "ws.attrsend.getcryptor.mode";
    public final static String ATTR_SEND_WS_POST_CRYPTORTYPE_KEY		= "ws.attrsend.postcryptor.type";
    public final static String ATTR_SEND_WS_READ_CRYPTORTYPE_KEY		= "ws.attrsend.readcryptor.type";
    public final static String ATTR_SEND_WS_RETRYCOUNT_KEY				= "ws.attrsend.retry";
    public final static String ATTR_SEND_WS_CONNECT_TIMEOUT_KEY			= "ws.attrsend.connect.timeout";
    public final static String ATTR_SEND_WS_READ_TIMEOUT_KEY			= "ws.attrsend.read.timeout";

    public final static String ATTR_CHECK_WS_PROPERTY_KEY				= "ws.attrcheck.property";
    public final static String ATTR_CHECK_WS_URLSORTER_PATTERN_KEY		= "ws.attrcheck.pattern";
    public final static String ATTR_CHECK_WS_CRYPTORTYPE_KEY			= "ws.attrcheck.getcryptor.type";
    public final static String ATTR_CHECK_WS_CRYPTORMODE_KEY			= "ws.attrcheck.getcryptor.mode";
    public final static String ATTR_CHECK_WS_POST_CRYPTORTYPE_KEY		= "ws.attrcheck.postcryptor.type";
    public final static String ATTR_CHECK_WS_READ_CRYPTORTYPE_KEY		= "ws.attrcheck.readcryptor.type";
    public final static String ATTR_CHECK_WS_RETRYCOUNT_KEY				= "ws.attrcheck.retry";
    public final static String ATTR_CHECK_WS_CONNECT_TIMEOUT_KEY		= "ws.attrcheck.connect.timeout";
    public final static String ATTR_CHECK_WS_READ_TIMEOUT_KEY			= "ws.attrcheck.read.timeout";


    public final static String ATTR_LOCAL_CAMPAIGNS_WS_PROPERTY_KEY					= "ws.localcampaigns.property";
    public final static String ATTR_LOCAL_CAMPAIGNS_WS_URLSORTER_PATTERN_KEY		= "ws.localcampaigns.pattern";
    public final static String ATTR_LOCAL_CAMPAIGNS_WS_CRYPTORTYPE_KEY				= "ws.localcampaigns.getcryptor.type";
    public final static String ATTR_LOCAL_CAMPAIGNS_WS_CRYPTORMODE_KEY				= "ws.localcampaigns.getcryptor.mode";
    public final static String ATTR_LOCAL_CAMPAIGNS_WS_POST_CRYPTORTYPE_KEY			= "ws.localcampaigns.postcryptor.type";
    public final static String ATTR_LOCAL_CAMPAIGNS_WS_READ_CRYPTORTYPE_KEY			= "ws.localcampaigns.readcryptor.type";
    public final static String ATTR_LOCAL_CAMPAIGNS_WS_RETRYCOUNT_KEY				= "ws.localcampaigns.retry";
    public final static String ATTR_LOCAL_CAMPAIGNS_WS_CONNECT_TIMEOUT_KEY			= "ws.localcampaigns.connect.timeout";
    public final static String ATTR_LOCAL_CAMPAIGNS_WS_READ_TIMEOUT_KEY				= "ws.localcampaigns.read.timeout";

    public final static String LOCAL_CAMPAIGNS_JIT_WS_PROPERTY_KEY					= "ws.localcampaignsjit.property";
    public final static String LOCAL_CAMPAIGNS_JIT_WS_URLSORTER_PATTERN_KEY		    = "ws.localcampaignsjit.pattern";
    public final static String LOCAL_CAMPAIGNS_JIT_WS_CRYPTORTYPE_KEY				= "ws.localcampaignsjit.getcryptor.type";
    public final static String LOCAL_CAMPAIGNS_JIT_WS_CRYPTORMODE_KEY				= "ws.localcampaignsjit.getcryptor.mode";
    public final static String LOCAL_CAMPAIGNS_JIT_WS_POST_CRYPTORTYPE_KEY			= "ws.localcampaignsjit.postcryptor.type";
    public final static String LOCAL_CAMPAIGNS_JIT_WS_READ_CRYPTORTYPE_KEY			= "ws.localcampaignsjit.readcryptor.type";
    public final static String LOCAL_CAMPAIGNS_JIT_WS_RETRYCOUNT_KEY	            = "ws.localcampaignsjit.retry";
    public final static String LOCAL_CAMPAIGNS_JIT_WS_READ_TIMEOUT_KEY              = "ws.localcampaignsjit.read.timeout";
    public final static String LOCAL_CAMPAIGNS_JIT_WS_CONNECT_TIMEOUT_KEY           = "ws.localcampaignsjit.connect.timeout";

    public final static String INBOX_WS_URLSORTER_PATTERN_KEY			= "ws.inbox.pattern";
    public final static String INBOX_WS_READ_CRYPTORTYPE_KEY			= "ws.inbox.readcryptor.type";
    public final static String INBOX_WS_POST_CRYPTORTYPE_KEY			= "ws.inbox.postcryptor.type";
    public final static String INBOX_WS_RETRYCOUNT_KEY					= "ws.inbox.retry";
    public final static String INBOX_WS_CONNECT_TIMEOUT_KEY				= "ws.inbox.connect.timeout";
    public final static String INBOX_WS_READ_TIMEOUT_KEY				= "ws.inbox.read.timeout";

    // Default Metric JSON webservice parameters
    public final static String METRIC_WS_URLSORTER_PATTERN_KEY		    = "ws.metric.json.pattern";
    public final static String METRIC_WS_CRYPTORTYPE_KEY				= "ws.metric.json.getcryptor.type";
    public final static String METRIC_WS_CRYPTORMODE_KEY				= "ws.metric.json.getcryptor.mode";
    public final static String METRIC_WS_POST_CRYPTORTYPE_KEY			= "ws.metric.json.postcryptor.type";
    public final static String METRIC_WS_READ_CRYPTORTYPE_KEY			= "ws.metric.json.readcryptor.type";
    public final static String METRIC_WS_READ_TIMEOUT_KEY              = "ws.metric.json.read.timeout";
    public final static String METRIC_WS_CONNECT_TIMEOUT_KEY           = "ws.metric.json.connect.timeout";

    public final static String DISPLAY_RECEIPT_WS_CRYPTORTYPE_KEY	    =   "ws.displayreceipt.getcryptor.type";
    public final static String DISPLAY_RECEIPT_WS_RETRYCOUNT_KEY	    =   "ws.displayreceipt.retry";
    public final static String METRIC_WS_RETRYCOUNT_KEY	                =   "ws.metrics.retry";

    public final static String LOCAL_CAMPAIGNS_WS_INITIAL_DELAY         = "lc.wsdelay.initial";
    public final static String WS_CIPHERV2_LAST_FAILURE_KEY             = "ws.cipherv2.lastfailure";
    public final static String DEFAULT_RETRY_NUMBER_KEY					= "ws.defaultRetry";
    public final static String DEFAULT_CONNECT_TIMEOUT_KEY				= "ws.defaultconnectTimeout";
    public final static String DEFAULT_READ_TIMEOUT_KEY					= "ws.defaultreadTimeout";
    public final static String INSTALL_ID_KEY 							= "app.install.id";
    public final static String INSTALL_TIMESTAMP_KEY 					= "app.install.timestamp";
    public final static String TASK_EXECUTOR_MIN_POOL					= "app.executor.minpool";
    public final static String TASK_EXECUTOR_MAX_POOL					= "app.executor.maxpool";
    public final static String TASK_EXECUTOR_THREADTTL					= "app.executor.threadttl";
    public final static String SCHEME_CODE_PATTERN						= "app.scheme.codepattern";
    public final static String CUSTOM_ID								= "app.id.custom";
    public final static String USER_DATA_VERSION						= "app.profile.version";
    public final static String PROJECT_KEY						        = "app.project.key";
    public final static String SERVER_TIMESTAMP							= "ws.server.timestamp";
    public final static String EVENT_TRACKER_INITIAL_DELAY				= "tracker.delay.initial";
    public final static String EVENT_TRACKER_MAX_DELAY					= "tracker.delay.max";
    public final static String EVENT_TRACKER_BATCH_QUANTITY				= "tracker.batch.quantity";
    public final static String EVENT_TRACKER_EVENTS_LIMIT				= "tracker.db.limit";
    public final static String PUSH_REGISTRATION_ID_KEY					= "push.registration.id";
    public final static String PUSH_REGISTRATION_PROVIDER_KEY			= "push.registration.provider";
    public final static String PUSH_REGISTRATION_SENDERID_KEY			= "push.registration.sender_id";

    public final static String PUSH_REGISTRATION_GCPPROJECTID_KEY		= "push.registration.gcp_project_id";
    public final static String PUSH_APP_VERSION_KEY						= "push.appversion";
    public final static String PUSH_NOTIF_TYPE							= "push.notiftype";
    public final static String PUSH_NOTIF_LAST_AUTH_STATUS_SENT		    = "push.notif.last_auth_status_sent";

    public final static String USER_DATA_CHANGESET						= "user_profile.data.version";
    public final static String USER_DATA_TRANSACTION_ID					= "user_profile.data.transactionID";
    public final static String USER_PROFILE_LANGUAGE_KEY                = "u_c_l";
    public final static String USER_PROFILE_REGION_KEY                  = "u_c_r";

    public final static String LIB_CURRENTVERSION_KEY					= "app.version.current";
    public final static String LIB_PREVIOUSVERSION_KEY					= "app.version.previous";

    public final static String DISPLAY_RECEIPTS_JOB_CANCELLED_KEY	    = "displayreceipts.jobs.already_cancelled";

    public final static String SHARED_PREFS_STORAGE_VERSION				= "app.shared_prefs.version";

    public final static String DATA_COLLECTION_CONFIG_KEY			    = "data.privacy.config";

    // DNS Fallback
    public final static String DNS_DOMAIN_KEY                           = "dns.domain.current";
    public static final String DNS_DOMAIN_ERROR_COUNT_KEY               = "dns.domain.current.error.count";
    public static final String DNS_DOMAIN_ERROR_UPDATE_DATE             = "dns.domain.current.error.last_update.date";
    public static final String DNS_DOMAIN_LAST_UPDATE_DATE              = "dns.domain.current.last_update.date";
    public static final String DNS_DOMAIN_LAST_CHECK_DATE               = "dns.domain.original.last_check.date";
}
//@formatter:on
